@@ -11,8 +11,9 @@ https://www.xmswiki.com/wiki/SMS:2D_Mesh_Files_*.2dm.
 
 from . import errors, utils
 from ._entities import (Element, Element2L, Element3L, Element3T, Element4Q,
-                        Element6T, Element8Q, Element9Q, LinearElement, Node,
-                        NodeString, QuadrilateralElement, TriangularElement)
+                        Element6T, Element8Q, Element9Q, Entity, LinearElement,
+                        Node, NodeString, QuadrilateralElement,
+                        TriangularElement)
 from ._read import Reader, ReaderBase
 from ._write import Writer
 
@@ -25,6 +26,7 @@ __all__ = [
     'Element6T',
     'Element8Q',
     'Element9Q',
+    'Entity',
     'errors',
     'LinearElement',
     'Node',
@@ -37,4 +39,4 @@ __all__ = [
     'Writer'
 ]
 
-__version__ = '0.2.0post2'
+__version__ = '0.2.1'
